# pyqt-svg-abstractbutton
PyQt QAbstractButton for <a href="https://github.com/yjg30737/pyqt-svg-button.git">pyqt-svg-button</a> and <a href="https://github.com/yjg30737/pyqt-svg-toolbutton.git">pyqt-svg-toolbutton</a>'s style and feature
